const request = require('request');

module.exports = (req, res) => {
  const { entityId, apiKey }  = req.query;
  if (!entityId) return res.status(422).send({ error: 'missing required field: entityId' });
  if (!apiKey) return res.status(422).send({error: 'missing required field: apiKey'});

  const auth = `Basic ${Buffer.from('X:' + apiKey).toString('base64')}`;
  const options = {
    url: `https://next.leadconduit.com/entities/${entityId}`,
    method: 'GET',
    headers: {
      Accept: 'application/json',
      Authorization: auth,
    }
  };
  request(options, (err, response, body) => {
    if (err) {
      return res.status(422).send({ error: err.message });
    }
    else if (response.statusCode !== 200) {
      let message = '';
      try {
        message = JSON.parse(body).error
      }
      catch (e) {
        message = `Error (${response.statusCode}); unable to parse response from LeadConduit'`;
      }
      return res.status(response.statusCode).send({ error: message });
    }
    res.status(200).send(body);
  });

};
